DEprot.RMSE class

Slots

original.DEprot.object

Object of class DEprot used to compute the RMSE. Class: "ANY".

percentage.test

Percentage of the total proteins that should be used to perform the comparisons. Class: "ANY".

seed

Seed used for the randomization. Class: "ANY".

fraction.missing.values

Fraction of missing values in the original table. Class: "ANY".

test.dataset

Subset of the original table used for the comparisons. Class: "ANY".

imputed.objects

List of the output of impute.counts (class DEprot) using the different imputation methods. Class: "ANY".

RMSE.tables

List of data.frames, one per tested imputation method, containing the coordinates of the imputed values and including the following columns (Class: "ANY".):

row.id:

id of the row (protein)

col.id:

id of the column (sample)

expected.values:

value measured in the experiment

imputation.method:

id of the method used for the imputation

imputed.values:

value imputed by DEprot

residuals:

difference of the the values, imputed - expected

sq.residuals:

the squared value of the residuals

RMSE.scores

A table indicating the methods and the corresponding RMSE score. Class: "ANY".

correlation.plots

A list of ggplot objects with the correlation between observed/expected and imputed values. Class: "ANY".

density.residuals

A list of ggplot objects depicting the distribution of the residuals. Class: "ANY".

masking

List describing how the values of the test dataset have been hidden, containing the following elements (Class: "ANY".):

mode:

masking actually applied, "MCAR" or "intensity". It reports "MCAR" also when the intensity-dependent masking was required but none of the dropout curves could be estimated

dropout.by:

level at which the dropout curves have been estimated, "group" or "sample"

dropout.curves:

list with the intercept and the slope of the logistic curve estimated for each group of replicates (or each sample), NULL when the masking is "MCAR"

max.NA.per.row:

maximum number of missing values that a protein could already have to enter the test dataset

max.NA.fraction:

maximum fraction of missing values that a protein could reach after the masking