Extension of the DEprot class: it stores the same data and pre-processing information, plus the results of the differential analyses. All the slots of DEprot are inherited and behave identically.
analyses.result.listList containing the differential results for each contrast. Class: "ANY". The list contains the following elements:
results: a data.frame containing the results of the analyses; includes average expression of each group, basemean, foldchange, pvalue and p.adj, test statistic, degrees of freedom and differential.status
n.diff: a summary table showing the number of proteins in each differential expression status (up/down/unresponsive, null)
PCA.data: output of perform.PCA for the subset of samples analyzed in a specific contrast
PCA.plots: combination of 3 plots: scatter PC1-vs-PC2, scatter PC2-vs-PC3, and cumulative bar plot
correlations: combination of Pearson and Spearman correlation heatmaps (obtained by plot.correlation.heatmap) for the subset of samples analyzed in a specific contrast
volcano: volcano plot showing the log2(FoldChange) x -log10(p.adjusted) of differential expression results; it can be regenerated using plot.volcano
MA.plot: MA-plot showing the log2(basemean) x log2(FoldChange) of differential expression results; it can be regenerated using plot.MA
contrastsList of contrasts. each contrast is a vector indicating, in the order: metadata.table.column - groupA - groupB; (groupA / group B). Class: "ANY".
differential.analyses.paramsList of parameters used to run the differential analyses (fold change thresholds, p-value threshold, p-adjustment method, etc.). Class: "ANY".